@@ -18,7 +18,7 @@ class ctc_refundable_individual_maximum(Variable):
         return person("ctc_individual_maximum", period)
 
     def formula_2018(person, period, parameters):
-        amount = person("ctc_individual_maximum", period)
+        amount = person("ctc_child_individual_maximum", period)
         ctc = parameters(period).gov.irs.credits.ctc
         return min_(amount, ctc.refundable.individual_max)
 
